@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls import patterns, url
 
 urlpatterns = patterns('',
     url(r'^list$', 'concepts.views.list_tags', name='concepts-autocomplete-list'),
